import sys
import os.path
import polib


def main():
    if len(sys.argv) != 2:
        print "USAGE: %s <po_file_to_check>\n" % sys.argv[0]
        sys.exit(1)

    po_file_path = sys.argv[1]

    if not os.path.exists(po_file_path):
        print "File not found %s\n" % po_file_path
        sys.exit(2)

    po = polib.pofile(po_file_path)

    UNTRANSLATED = 0
    for entry in po.untranslated_entries():
        UNTRANSLATED += 1
        print "UNTRANSLATED\t", entry.msgid.encode('utf-8')

    FUZZY = 0
    for entry in po.fuzzy_entries():
        FUZZY += 1
        print "FUZZY\t", entry.msgid.encode('utf-8'), entry.msgstr.encode('utf-8')

    if FUZZY or UNTRANSLATED:
        print '\n----------'
        if FUZZY:
            print "%d FUZZY string found." % FUZZY
        if UNTRANSLATED:
            print "%d UNTRANSLATED string found." % UNTRANSLATED
        print '----------'
        print "Edit: %s\n\n" % os.path.abspath(po_file_path)
        sys.exit(100)

    print "%s: PO File OK\n\n" % po_file_path
    sys.exit(0)



# -*- coding: utf-8 -*-
"""Python packaging."""
from os.path import abspath, dirname, join
from setuptools import setup


def read_relative_file(filename):
    """Returns contents of the given file, which path is supposed relative
    to this module."""
    with open(join(dirname(abspath(__file__)), filename)) as f:
        return f.read()

name = 'check_po'
version = read_relative_file('VERSION').strip()
readme = read_relative_file('README')
requirements = ['setuptools',
                'polib'
                ]
entry_points = {
    'console_scripts': [
        'check_po = check_po:main',
    ]
}

if __name__ == '__main__':  # ``import setup`` doesn't trigger setup().
    setup(name=name,
          version=version,
          description="""Check_po to verify if everything is translated
                         and that no fuzzy are still here.""",
          long_description=readme,
          classifiers=[
              "Programming Language :: Python",
              'License :: Other/Proprietary License',
          ],
          keywords='',
          author='Rémy Hubscher',
          author_email='hubscher.remy@gmail.com',
          url='https://github.com/novagile/%s' % name,
          license='WTFPL',
          packages=['check_po'],
          include_package_data=True,
          zip_safe=False,
          install_requires=requirements,
          entry_points=entry_points,
          )
